@@ -1,4 +1,4 @@
-from typing import List, Tuple, Union, Optional, Mapping, Iterable, Sequence, Any
+from typing import List, Tuple, Union, Optional, Mapping, Iterable, Sequence, Any, Literal
 from numbers import Integral
 from collections import abc
 from collections.abc import MutableMapping
@@ -244,9 +244,8 @@ class MuData:
         varp: Optional[Union[np.ndarray, Mapping[str, Sequence[Any]]]] = None,
         obsmap: Optional[Mapping[str, Sequence[int]]] = None,
         varmap: Optional[Mapping[str, Sequence[int]]] = None,
-        axis: anndata.compat.Literal[0, 1] = 0,
+        axis: Literal[0, 1] = 0,
     ):
-
         return cls(
             data={k: (v if isinstance(v, AnnData) else AnnData(**v)) for k, v in mod.items()},
             obs=obs,
@@ -1200,7 +1199,7 @@ class MuData:
         backed_at = f" backed at {str(self.filename)!r}" if self.isbacked else ""
         view_of = "View of " if self.is_view else ""
         descr = f"{view_of}MuData object with n_obs × n_vars = {n_obs} × {n_vars}{backed_at}"
-        for attr in ["obs", "var", "obsm", "varm", "obsp", "varp"]:
+        for attr in ["obs", "var", "uns", "obsm", "varm", "obsp", "varp"]:
             if hasattr(self, attr) and getattr(self, attr) is not None:
                 keys = list(getattr(self, attr).keys())
                 if len(keys) > 0:
